Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(229)

Unified Diff: net/http/http_network_transaction.h

Issue 1781003003: Implement referred Token Bindings (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix nits; add unittest Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_network_transaction.h
diff --git a/net/http/http_network_transaction.h b/net/http/http_network_transaction.h
index 5b554afd8e8805ae16a931134ba3d7dd52fbc6d0..2b9f5162a3972012a701e1174e32532a51959b45 100644
--- a/net/http/http_network_transaction.h
+++ b/net/http/http_network_transaction.h
@@ -341,9 +341,11 @@ class NET_EXPORT_PRIVATE HttpNetworkTransaction
// The SSLFailureState which caused the last TLS version fallback.
SSLFailureState fallback_failure_state_;
- // Key to use for signing message in Token Binding header.
- scoped_ptr<crypto::ECPrivateKey> token_binding_key_;
- // Object to manage lookup of |token_binding_key_|.
+ // Keys to use for signing message in Token Binding header.
+ scoped_ptr<crypto::ECPrivateKey> provided_token_binding_key_;
+ scoped_ptr<crypto::ECPrivateKey> referred_token_binding_key_;
+ // Object to manage lookup of |provided_token_binding_key_| and
+ // |referred_token_binding_key_|.
ChannelIDService::Request token_binding_request_;
HttpRequestHeaders request_headers_;

Powered by Google App Engine
This is Rietveld 408576698